@@ -9,9 +9,11 @@
 #'    Note here, the NULL hypothesis is that empirical data are consistent with
 #'    the NULL distribution, and the alternative hypothesis is that the data
 #'    are NOT consistent. This function SHOULD NOT be used to compare two 
-#'    empirical networks using Chi-squared tests, as the function assumes 
-#'    x.summary and y.summary represent observed and expected values, 
-#'    respectively.
+#'    empirical networks, as the function assumes x.summary and y.summary 
+#'    represent observed and expected values, respectively. Please note that 
+#'    this is a function of convience that is essentially a wrapper for the 
+#'    binom.test function, that allows users to easily compare contact
+#'    networks created using our pipeline of contact:: functions.
 #'    
 #' This function was inspired by the methods described by Spiegel et al. 2016. 
 #'    They determined individuals to be expressing social behavior when nodes 
@@ -379,7 +381,7 @@ contactCompare_binom<-function(x.summary, y.summary, x.potential, y.potential =
         #rand.success = sum(randDurations) #number of "successful" contact events in the randomized set
         #rand.fail = (maxDurations.rand - sum(randDurations)) #number of "failed" contact events in the randomized set
         
-        expectedProb1 <- expectedProb[1] #unline the chisq.test function, the binom.test function only accepts a vector of length one as the probability argument
+        expectedProb1 <- expectedProb[1] #unlike the chisq.test function, the binom.test function only accepts a vector of length one as the probability argument
 
         assign("last.warning", NULL, envir = baseenv()) #clears the warnings
         
